@@ -1,12 +1,13 @@
 """
-The base Class and interface for Classes
-use to transform strings of various forms
-to model objects and model objects to strings
-of various forms.
+Turn entities to and fro various representations.
+
+This is the base Class and interface Class used to
+transform strings of various forms to model objects
+and model objects to strings of various forms.
 """
 
 from tiddlyweb.serializer import NoSerializationError
-from tiddlyweb.model.tiddler import string_to_tags_list
+from tiddlyweb.model.tiddler import tags_list_to_string, string_to_tags_list
 
 
 class SerializationInterface(object):
@@ -22,16 +23,20 @@ class SerializationInterface(object):
     in each Serialization.
 
     *_as returns a string form of the entity, perhaps as
-    HTML, Text, YAML, Atom, whatever the Serialzation does.
+    HTML, Text, YAML, Atom, whatever the Serialization does.
 
     as_* takes a provided entity and string and updates
     the skeletal entity to represent the information
-    contain in the string (in the Serialization format).
+    contained in the string (in the Serialization format).
 
-    There are also two supporting methods, list_recipes()
-    and list_bags() that provide convince methods for
-    presenting a collection of either in the Serialization
-    form. A string is returned.
+    There are also three supporting methods, list_tiddlers,
+    list_recipes() and list_bags() that provide convenience
+    methods for presenting a collection of either in the
+    Serialization form. A string is returned.
+
+    If a method doesn't exist a NoSerializationError is raised
+    and the calling code is expected to do something intelligent
+    when trapping it.
     """
 
     def __init__(self, environ=None):
@@ -102,19 +107,14 @@ class SerializationInterface(object):
 
     def as_tags(self, string):
         """
-        Not called directly, put made public for future
+        Not called directly, but made public for future
         use. Turn a string into a list of tags.
         """
         return string_to_tags_list(string)
 
     def tags_as(self, tags):
         """
-        Not called directly, put made public for future
+        Not called directly, but made public for future
         use. Turn a list of tags into a serialized list.
         """
-        tag_string_list = []
-        for tag in tags:
-            if ' ' in tag:
-                tag = '[[%s]]' % tag
-            tag_string_list.append(tag)
-        return u' '.join(tag_string_list)
+        return tags_list_to_string(tags)
